@@ -1,5 +1,5 @@
 import argparse
-from .pycritty import subparsers, formatter
+from pycritty.cli import subparsers, formatter
 
 
 load_parser = subparsers.add_parser(
@@ -10,7 +10,7 @@ load_parser = subparsers.add_parser(
 )
 
 load_parser.add_argument(
-    'load_config',
+    'name',
     metavar='NAME',
     help='Name of the config you want to load',
 )
